library flutter_hkbyte_ui_beta;

import 'package:flutter/material.dart';

/// A Calculator.
class Calculator {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}

class ToggleButtonOption {
  String label;
  dynamic value;

  ToggleButtonOption({@required this.label, @required this.value});
}

class ToggleButton extends StatefulWidget {
  final List<ToggleButtonOption> options;
  final ValueChanged<ToggleButtonOption> onChanged;
  ToggleButton({Key key, @required this.options, this.onChanged})
      : super(key: key);

  @override
  _ToggleButtonState createState() => _ToggleButtonState();
}

class _ToggleButtonState extends State<ToggleButton> {
  GlobalKey actionKey;
  double height, width, xPosition, yPosition;
  var selectedToggle;

  List<ToggleButtonOption> _options;

  @override
  void initState() {
    actionKey = LabeledGlobalKey("Hello");
    _options = widget.options;
    // selectedToggle = _options[0];
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((timeStamp) {
      findToggleButtonData();
    });
  }

  void findToggleButtonData() {
    RenderBox renderBox = actionKey.currentContext.findRenderObject();
    height = renderBox.size.height;
    width = renderBox.size.width;
    Offset offset = renderBox.localToGlobal(Offset.zero);
    xPosition = offset.dx;
    yPosition = offset.dy;
    print(height);
    print(width);
    print(xPosition);
    print(yPosition);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        color: Colors.grey.shade300,
        borderRadius: BorderRadius.circular(7),
      ),
      child: Stack(
        children: [
          AnimatedPositioned(
            duration: Duration(milliseconds: 300),
            curve: Curves.ease,
            left: width != null
                ? (width / _options.length) * _options.indexOf(selectedToggle)
                : 0,
            width: width != null ? width / _options.length : 0,
            height: height != null ? height : 0,
            child: Container(
              margin: EdgeInsets.all(3),
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(5),
                  color: Colors.white,
                  boxShadow: [
                    BoxShadow(
                      offset: Offset(-1, 1),
                      blurRadius: 5,
                      color: Colors.grey.shade400,
                    ),
                  ]),
            ),
          ),
          Flex(
            key: actionKey,
            direction: Axis.horizontal,
            children: List.generate(
              _options.length,
              (index) => Flexible(
                flex: 1,
                fit: FlexFit.tight,
                child: GestureDetector(
                  onTap: () {
                    setState(() {
                      widget.onChanged(_options[index]);
                      selectedToggle = _options[index];
                    });
                  },
                  child: Container(
                    color: Colors.transparent,
                    padding: EdgeInsets.all(10),
                    alignment: Alignment.center,
                    child: Text(_options[index].label),
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
